==> dokuwiki-2011.05.25a.tgz: dokuwiki/lib/plugins/plugin/lang/fa/lang.php <==
<?php
/**
 * Persian language file
 *
 * @author behrad eslamifar <behrad_es@yahoo.com)
 * @author Mohsen Firoozmandan <info@mambolearn.com>
 * @author omidmr@gmail.com
 * @author Omid Mottaghi <omidmr@gmail.com>
 * @author Mohammad Reza Shoaei <shoaei@gmail.com>
 */
$lang['menu']                  = 'مدیریت افزونه‌ها';
$lang['download']              = 'دریافت و نصب افزونه';
$lang['manage']                = 'افزونه‌های نصب شده';
$lang['btn_info']              = 'مشخصات';
$lang['btn_update']            = 'بروزرسانی';
$lang['btn_delete']            = 'حذف';
$lang['btn_settings']          = 'تنظیمات';
$lang['btn_download']          = 'دانلود';
$lang['btn_enable']            = 'ذخیره';
$lang['url']                   = 'آدرس';
$lang['installed']             = 'نصب شده:';
$lang['lastupdate']            = 'آخرین بروزرسانی:';
$lang['source']                = 'منبع:';
$lang['unknown']               = 'ناشناس';
$lang['updating']              = 'در حال به روز رسانی...';
$lang['updated']               = 'افزونه‌ی %s با موفقیت به روز رسانی شد';
$lang['updates']               = 'افزونه‌های زیر با موفقیت به روز رسانی شده است.';
$lang['update_none']           = 'به روز رسانی‌ای یافت نشد .';
$lang['deleting']              = 'در حال حذف...';
$lang['deleted']               = 'افزونه‌ی %s پاک شد.';
$lang['downloading']           = 'در حال دریافت...';
$lang['downloaded']            = 'افزونه‌ی %s با موفقیت نصب شد';
$lang['downloads']             = 'افزونه‌های زیر با موفقیت نصب شدند:';
$lang['download_none']         = 'هیچ افزونه‌ای یافت نشد، یا یک مشکل ناشناخته در زمان دریافت و نصب پیش آمده است.';
$lang['plugin']                = 'افزونه:';
$lang['components']            = 'کامپوننت';
$lang['noinfo']                = 'این افزونه هیچ اطلاعاتی را برنگردانده است، ممکن است بی‌اعتبار باشد.';
$lang['name']                  = 'اسم:';
$lang['date']                  = 'تاریخ:';
$lang['type']                  = 'نوع:';
$lang['desc']                  = 'توضیحات:';
$lang['author']                = 'نویسنده:';
$lang['www']                   = 'وب‌سایت:';
$lang['error']                 = 'یک مشکل ناشناخته پیش آمده.';
$lang['error_download']        = 'توانایی دریافت افزونه‌ی %s نمی‌باشد.';
$lang['error_badurl']          = 'آدرس مشکل دارد - توانایی تشخیص نام فایل از آدرس وجود ندارد';
$lang['error_dircreate']       = 'امکان ایجاد شاخه‌ی موقتی برای دریافت فایل نیست.';
$lang['error_decompress']      = 'باز کردن فایل با مشکل مواجه شد. این اشکال ممکن است به خاطر دریافت ناقصِ فایل باشد که باید دوباره تلاش کنید، یا فرمت فشرده‌سازی شناخته شده نیست، که باید این افزونه رو دستی نصب کنید.';
$lang['error_copy']            = 'توانایی کپی کردن فایل‌های افزونه‌ی <em>%s</em> در زمان نصب وجود ندارد. ممکن است دسترسی شاخه‌ی افزونه‌ها مشکل داشته باشد. این مشکل ممکن است باعث نصب ناقص افزونه شود و ویکی را با مشکل مواجه کند.';
$lang['error_delete']          = 'توانایی حذف افزونه‌ی <em>%s</em> وجود ندارد. این مشکل به خاطر دسترسی فایل یا شاخه‌ی افزونه پیش می‌آید.';
$lang['enabled']               = 'افزونه‌ی %s فعال شد.';
$lang['notenabled']            = 'افزونه‌ی %s قابلیت فعال کردن ندارد، دسترسی‌ها را چک کنید.';
$lang['disabled']              = 'افزونه‌ی %s غیرفعال شد.';
$lang['notdisabled']           = 'افزونه‌ی %s قابلیت غیرفعال کردن ندارد، دسترسی‌ها را چک کنید.';
$lang['packageinstalled']      = 'بسته‌ی افزوده‌ها (%d افزونه%s: %s) با موفقیت نصب شد.';

==> dokuwiki-2012.10.13.tgz: dokuwiki/lib/plugins/plugin/lang/fa/lang.php <==
<?php
/**
 * Persian language file
 *
 * @author behrad eslamifar <behrad_es@yahoo.com)
 * @author Mohsen Firoozmandan <info@mambolearn.com>
 * @author omidmr@gmail.com
 * @author Omid Mottaghi <omidmr@gmail.com>
 * @author Mohammad Reza Shoaei <shoaei@gmail.com>
 * @author Milad DZand <M.DastanZand@gmail.com>
 */
$lang['menu']                  = 'مدیریت افزونه‌ها';
$lang['download']              = 'دریافت و نصب افزونه';
$lang['manage']                = 'افزونه‌های نصب شده';
$lang['btn_info']              = 'مشخصات';
$lang['btn_update']            = 'بروزرسانی';
$lang['btn_delete']            = 'حذف';
$lang['btn_settings']          = 'تنظیمات';
$lang['btn_download']          = 'دانلود';
$lang['btn_enable']            = 'ذخیره';
$lang['url']                   = 'آدرس';
$lang['installed']             = 'نصب شده:';
$lang['lastupdate']            = 'آخرین بروزرسانی:';
$lang['source']                = 'منبع:';
$lang['unknown']               = 'ناشناس';
$lang['updating']              = 'در حال به روز رسانی...';
$lang['updated']               = 'افزونه‌ی %s با موفقیت به روز رسانی شد';
$lang['updates']               = 'افزونه‌های زیر با موفقیت به روز رسانی شده است.';
$lang['update_none']           = 'به روز رسانی‌ای یافت نشد .';
$lang['deleting']              = 'در حال حذف...';
$lang['deleted']               = 'افزونه‌ی %s پاک شد.';
$lang['downloading']           = 'در حال دریافت...';
$lang['downloaded']            = 'افزونه‌ی %s با موفقیت نصب شد';
$lang['downloads']             = 'افزونه‌های زیر با موفقیت نصب شدند:';
$lang['download_none']         = 'هیچ افزونه‌ای یافت نشد، یا یک مشکل ناشناخته در زمان دریافت و نصب پیش آمده است.';
$lang['plugin']                = 'افزونه:';
$lang['components']            = 'کامپوننت';
$lang['noinfo']                = 'این افزونه هیچ اطلاعاتی را برنگردانده است، ممکن است بی‌اعتبار باشد.';
$lang['name']                  = 'اسم:';
$lang['date']                  = 'تاریخ:';
$lang['type']                  = 'نوع:';
$lang['desc']                  = 'توضیحات:';
$lang['author']                = 'نویسنده:';
$lang['www']                   = 'وب‌سایت:';
$lang['error']                 = 'یک مشکل ناشناخته پیش آمده.';
$lang['error_download']        = 'توانایی دریافت افزونه‌ی %s نمی‌باشد.';
$lang['error_badurl']          = 'آدرس مشکل دارد - توانایی تشخیص نام فایل از آدرس وجود ندارد';
$lang['error_dircreate']       = 'امکان ایجاد شاخه‌ی موقتی برای دریافت فایل نیست.';
$lang['error_decompress']      = 'باز کردن فایل با مشکل مواجه شد. این اشکال ممکن است به خاطر دریافت ناقصِ فایل باشد که باید دوباره تلاش کنید، یا فرمت فشرده‌سازی شناخته شده نیست، که باید این افزونه رو دستی نصب کنید.';
$lang['error_copy']            = 'توانایی کپی کردن فایل‌های افزونه‌ی <em>%s</em> در زمان نصب وجود ندارد. ممکن است دسترسی شاخه‌ی افزونه‌ها مشکل داشته باشد. این مشکل ممکن است باعث نصب ناقص افزونه شود و ویکی را با مشکل مواجه کند.';
$lang['error_delete']          = 'توانایی حذف افزونه‌ی <em>%s</em> وجود ندارد. این مشکل به خاطر دسترسی فایل یا شاخه‌ی افزونه پیش می‌آید.';
$lang['enabled']               = 'افزونه‌ی %s فعال شد.';
$lang['notenabled']            = 'افزونه‌ی %s قابلیت فعال کردن ندارد، دسترسی‌ها را چک کنید.';
$lang['disabled']              = 'افزونه‌ی %s غیرفعال شد.';
$lang['notdisabled']           = 'افزونه‌ی %s قابلیت غیرفعال کردن ندارد، دسترسی‌ها را چک کنید.';
$lang['packageinstalled']      = 'بسته افزونه (%d افزونه: %s) به درستی نصب شد.';
